/* SPDX-License-Identifier: LGPL-2.1-only */
/*
 * Copyright (c) 2013 Thomas Graf <tgraf@suug.ch>
 */

#ifndef NETLINK_DUMMY_LINK_INFO_API_H_
#define NETLINK_DUMMY_LINK_INFO_API_H_

#include <netlink/netlink.h>
#include <netlink/route/link.h>

#ifndef _NL_NO_WARN_DEPRECATED_HEADER
#warning "You are including a deprecated header file, include <netlink/route/link.h>."
#endif

#endif
